
	subroutine LS(jd,rsat,rls,vls,dt,SUNOFF,MOONOFF,LSOUT,J38ON)

! Given :
!         Julian Day (jd)
!         Spaceraft position vector rsat(3)
!         time interval (dt)
! Return:
!         Perturbation on position vector, rls(3)
!         Perturbation on velocity vector, vls(3)
!
! DWM 5-feb-92 

	implicit none

	double precision rls(3),vls(3),dt,jd,ang,dp
	double precision gmsun,gmmoon,rsun(3),rmoon(3),rsat(3)

C-gam	double precision ras,decs,lamdas,betas,ms,rs,rsun(3)
	double precision ras,decs,lamdas,betas,ms,rs

C-gam	double precision ram,decm,rm,rmoon(3),rsun1(3),rmoon1(3)
	double precision ram,decm,rm,         rsun1(3),rmoon1(3)

!	double precision nsat(3),nsun(3),nmoon(3),nsun1(3),nmoon1(3)
	double precision asun(3),amoon(3),rs1,rm1,a(3)
	double precision asun1(3),amoon1(3),asun2(3),amoon2(3)
	double precision gmearth,j(14),lp(14),lp1(14),re,s,r1
        double precision theta(3),phi(3),r(3),k(3),aearth(3),c1,c2

	logical MOONOFF,SUNOFF,LSOUT,J38ON
	integer i

	gmsun  = 1.32686D20
	gmmoon = 4.90280D12


! introduce J3 and J4 earth perturbations
! DWM 30-sep-92
! data from Astrophysical formulas Lang pg. 494
! Legendre polynomials pg 541 Arfken

	if(J38ON) then

	gmearth=3.986032D14
        re     =6378140.0d0


	k(1) =  0.0d0
	k(2) =  0.0d0
	k(3) =  1.0d0

	call DOTP(rsat,rsat,dp,ang)
	r1=dsqrt(dp)
 
	call NORM(rsat,r)

	call VECP(k,r,phi)
	call NORM(phi,phi)

	call VECP(phi,r,theta)



! work out Legendre Polynomials (lp) and first derivative (lp1)

	lp(1)=r(3)
	lp(2)=(3.0d0*(r(3)**2)-1.0d0)/2.0d0


	do i=3,14

	 lp(i)=(dble(2*i-1)*r(3)*lp(i-1)-dble(i-1)*lp(i-2))/dble(i)
	 lp1(i)=dble(i)*(lp(i-1)-r(3)*lp(i))/(1.0d0-r(3)**2)

	end do


	j(3)  = -2.56D-6
        j(4)  = -1.61D-6
	j(5)  = -0.210D-6
        j(6)  =  0.646D-6
	j(7)  = -0.333D-6
        j(8)  = -0.270D-6
	j(9)  = -0.053D-6
        j(10) = -0.054D-6
	j(11) =  0.302D-6
        j(12) = -0.357D-6
	j(13) = -0.114D-6
        j(14) = -0.179D-6

! s is derivative of Cos(theta)

	s=-1.0*dsin(dacos(r(3)))


	c1=0.0d0
	c2=0.0d0

	do i=3,14

	 c1=c1-dble(i+1)*j(i)*lp(i)*((re/r1)**i)
	 c2=c2+        s*j(i)*lp1(i)*((re/r1)**i)

	end do


	do i=1,3
	 aearth(i)=c1*r(i)+c2*theta(i)
	end do

	do i=1,3
	 aearth(i)=aearth(i)*gmearth/(r1**2)
	end do

	if(LSOUT) then
	write(*,*) 'J3/J4 perturbation'
	write(*,*) 'r, theta, phi '
	write(*,*) r(1),r(2),r(3)
	write(*,*) theta(1),theta(2),theta(3)
	write(*,*) phi(1),phi(2),phi(3)
	write(*,*) 'Legendre Poly: 3 to 14'
	write(*,*) (lp(i),i=3,14)
	write(*,*) 'Legendre Poly derivative : 3 to 14'
	write(*,*) (lp1(i),i=3,14)
	write(*,*) 'c1, c2'
	write(*,*) c1, c2
	write(*,*) 'aearth '
	write(*,*) aearth(1),aearth(2),aearth(3)
	end if

	end if

	if(LSOUT) then
	write(*,*) 'LS start:'
	write(*,*) 'jd,rsat,rls,vls,dt'
	write(*,*) jd
	write(*,*) rsat
	write(*,*) rls
	write(*,*) vls
	write(*,*) dt
	end if


	call  SUN(jd,ras,decs,lamdas,betas,ms,rs)
	ras=ras*15.0d0
	call  polar(rs,ras,decs,rsun)
	call  MOON(jd,ram,decm,rm)
	ram=ram*15.0d0
	call  polar(rm,ram,decm,rmoon)

	call DIFF(rsat,rsun,rsun1)
	call DIFF(rsat,rmoon,rmoon1)

	rs1=0.0d0
	rm1=0.0d0

	call DOTP(rsun1,rsun1,dp,ang)
	rs1=dsqrt(dp)
	call DOTP(rmoon1,rmoon1,dp,ang)
	rm1=dsqrt(dp)

	IF(LSOUT) then
	write(*,*) 'LS: SUN  ra,dec,rs,rsun'
	write(*,*) ras,decs,rs
        write(*,*) rsun(1),rsun(2),rsun(3)
	write(*,*) 'LS: MOON ra,dec,rm,rmoon'
	write(*,*) ram,decm,rm
        write(*,*) rmoon(1),rmoon(2),rmoon(3)
	write(*,*) 'LS: SUN wrt S/C rs1,rsun1'
	write(*,*) rs1
        write(*,*) rsun1(1),rsun1(2),rsun1(3)
	write(*,*) 'LS: MOON wrt S/C rm1 rmoon1'
	write(*,*) rm1
        write(*,*) rmoon1(1),rmoon1(2),rmoon1(3)
	end if




	do i=1,3

!	 asun(i)=gmsun*((rsun1(i)/(rs1**3))-(rsun(i)/(rs**3)))
!	 amoon(i)=gmmoon*((rmoon1(i)/(rm1**3))-(rmoon(i)/(rm**3)))

         asun1(i)= rsun1(i)/(rs1**3)
         asun2(i)= rsun(i)/(rs**3)
	 asun(i)=gmsun*(asun1(i)-asun2(i))

         amoon1(i)= rmoon1(i)/(rm1**3)
         amoon2(i)= rmoon(i)/(rm**3)
	 amoon(i)=gmmoon*(amoon1(i)-amoon2(i))


	 a(i)=asun(i)+amoon(i)

	 if(SUNOFF) then
	   a(i)=amoon(i)
	 end if	 
	 if(MOONOFF) then
	   a(i)=asun(i)
	 end if
	if(SUNOFF.and.MOONOFF) then
	   a(i)=0.0d0
	 end if	 
	 vls(i)=a(i)*dt
	 rls(i)=0.5d0*a(i)*(dt**2)
	end do

	if(LSOUT) then
	write(*,*) 'LS: amoon'
	write(*,*) amoon(1),amoon(2),amoon(3)
	write(*,*) 'LS: asun'
	write(*,*) asun(1),asun(2),asun(3)
	write(*,*) 'LS: atotal'
	write(*,*) a(1),a(2),a(3)
	write(*,*) 'LS: rls'
	write(*,*) rls(1),rls(2),rls(3)	
	write(*,*) 'LS: vls'
	write(*,*) vls(1),vls(2),vls(3)
	end if

	if(J38ON) then
	 do i=1,3
	   a(i)=a(i)+aearth(i)
	 end do
	end if



	return

	end
